# `lute3-khmer`

A Khmer parser for Lute (`lute3`).

## Installation

See the [Lute manual](https://luteorg.github.io/lute-manual/install/plugins.html).

## Usage

When this parser is installed, you can add "Khmer" as a
language to Lute, which comes with a simple story.
